@@ -1,35 +1,46 @@
-/*
-    SPDX-FileCopyrightText: 2011 Rafał Kułaga <rl.kulaga@gmail.com>
+/***************************************************************************
+                          finderchart.cpp  -  K Desktop Planetarium
+                             -------------------
+    begin                : Wed Jul 20 2011
+    copyright            : (C) 2011 by Rafał Kułaga
+    email                : rl.kulaga@gmail.com
+ ***************************************************************************/
 
-    SPDX-License-Identifier: GPL-2.0-or-later
-*/
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 
 #include "finderchart.h"
 
-#include "detailstable.h"
-#include "geolocation.h"
-#include "kstarsdatetime.h"
+#include "QTextDocument"
+#include "QTextDocumentFragment"
+#include "QTextTable"
+#include "QTextDocumentWriter"
+#include "QSvgGenerator"
+#include "QPainter"
+#include "kstars.h"
 #include "loggingform.h"
-
-#include <QLocale>
-#include <QTextDocument>
-#include <QTextDocumentFragment>
-#include <QTextDocumentWriter>
-#include <QTextTable>
+#include "detailstable.h"
+#include "kstarsdatetime.h"
+#include "geolocation.h"
 
 FinderChart::FinderChart() : KStarsDocument()
-{
-}
+{}
 
 void FinderChart::insertTitleSubtitle(const QString &title, const QString &subtitle)
 {
-    QTextCursor cursor(m_Document.get());
+    QTextCursor cursor(m_Document);
     cursor.movePosition(QTextCursor::Start);
 
     QTextBlockFormat titleBlockFmt;
     titleBlockFmt.setAlignment(Qt::AlignCenter);
 
-    if (!title.isEmpty())
+    if(!title.isEmpty())
     {
         QTextCharFormat titleCharFmt;
         QFont titleFont("Times", 20, QFont::Bold);
@@ -39,7 +50,7 @@ void FinderChart::insertTitleSubtitle(const QString &title, const QString &subti
         cursor.insertText(title);
     }
 
-    if (!subtitle.isEmpty())
+    if(!subtitle.isEmpty())
     {
         QTextCharFormat subtitleCharFmt;
         QFont subtitleFont("Times", 14);
@@ -82,18 +93,14 @@ void FinderChart::insertGeoTimeInfo(const KStarsDateTime &ut, GeoLocation *geo)
     cursor.insertText(i18n("Date, time and location: "), geoCharFmt);
 
     QString geoStr = geo->translatedName();
-    if (!geo->translatedProvince().isEmpty())
-    {
-        if (!geoStr.isEmpty())
-        {
+    if(!geo->translatedProvince().isEmpty()) {
+        if(!geoStr.isEmpty()) {
             geoStr.append(", ");
         }
         geoStr.append(geo->translatedProvince());
     }
-    if (!geo->translatedCountry().isEmpty())
-    {
-        if (!geoStr.isEmpty())
-        {
+    if(!geo->translatedCountry().isEmpty()) {
+        if(!geoStr.isEmpty()) {
             geoStr.append(", ");
         }
         geoStr.append(geo->translatedCountry());
@@ -101,8 +108,7 @@ void FinderChart::insertGeoTimeInfo(const KStarsDateTime &ut, GeoLocation *geo)
 
     geoFont.setBold(false);
     geoCharFmt.setFont(geoFont);
-    //cursor.insertText(QLocale().toString(ut.dateTime()) + ", " + geoStr, geoCharFmt);
-    cursor.insertText(QLocale().toString(ut) + ", " + geoStr, geoCharFmt);
+    cursor.insertText(KGlobal::locale()->formatDateTime(ut) + ", " + geoStr, geoCharFmt);
 
     cursor.insertBlock(QTextBlockFormat(), QTextCharFormat());
 }
@@ -123,7 +129,7 @@ void FinderChart::insertImage(const QImage &img, const QString &description, boo
     QTextBlockFormat blockFmt;
     blockFmt.setAlignment(Qt::AlignHCenter);
 
-    if (descriptionBelow)
+    if(descriptionBelow)
     {
         cursor.insertBlock(blockFmt, textFmt);
         cursor.insertImage(img);
