@@ -1,5 +1,6 @@
 /*
-    Copyright (C) 2010 Henry de Valence <hdevalence@gmail.com>
+    <one line to give the program's name and a brief idea of what it does.>
+    Copyright (C) <year>  <name of author>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,24 +20,25 @@
 
 #include "gnomonicprojector.h"
 
-GnomonicProjector::GnomonicProjector(const ViewParams &p) : Projector(p)
+GnomonicProjector::GnomonicProjector(const ViewParams& p)
+    : Projector(p)
 {
-    updateClipPoly();
+
 }
 
-Projector::Projection GnomonicProjector::type() const
+SkyMap::Projection GnomonicProjector::type() const
 {
-    return Gnomonic;
+    return SkyMap::Gnomonic;
 }
 
 double GnomonicProjector::radius() const
 {
-    return 2 * M_PI;
+    return 2*M_PI;
 }
 
 double GnomonicProjector::projectionK(double x) const
 {
-    return 1.0 / x;
+    return 1.0/x;
 }
 
 double GnomonicProjector::projectionL(double x) const
@@ -49,3 +51,4 @@ double GnomonicProjector::cosMaxFieldAngle() const
     //Don't let things approach infty.
     return 0.02;
 }
+
